@@ -8,14 +8,14 @@
 #include "spvm_native.h"
 
 enum {
-  STACK_INDEX_EXCEPTION = 511,
-  STACK_INDEX_MORTAL_STACK = 510,
-  STACK_INDEX_MORTAL_STACK_TOP = 509,
-  STACK_INDEX_MORTAL_STACK_CAPACITY = 508,
-  STACK_INDEX_MEMORY_BLOCKS_COUNT = 507,
-  STACK_INDEX_ARGS_WIDTH = 506,
-  STACK_INDEX_CALL_DEPTH = 505,
-  STACK_INDEX_STACK_OBJECT = 504,
+  SPVM_API_C_STACK_INDEX_EXCEPTION = 511,
+  SPVM_API_C_STACK_INDEX_MORTAL_STACK = 510,
+  SPVM_API_C_STACK_INDEX_MORTAL_STACK_TOP = 509,
+  SPVM_API_C_STACK_INDEX_MORTAL_STACK_CAPACITY = 508,
+  SPVM_API_C_STACK_INDEX_MEMORY_BLOCKS_COUNT = 507,
+  SPVM_API_C_STACK_INDEX_ARGS_WIDTH = 506,
+  SPVM_API_C_STACK_INDEX_CALL_DEPTH = 505,
+  SPVM_API_C_STACK_INDEX_ENV = 504,
 };
 
 /*
@@ -107,6 +107,7 @@ int64_t SPVM_API_get_field_long(SPVM_ENV* env, SPVM_VALUE* stack, SPVM_OBJECT* o
 float SPVM_API_get_field_float(SPVM_ENV* env, SPVM_VALUE* stack, SPVM_OBJECT* object, SPVM_RUNTIME_FIELD* field);
 double SPVM_API_get_field_double(SPVM_ENV* env, SPVM_VALUE* stack, SPVM_OBJECT* object, SPVM_RUNTIME_FIELD* field);
 SPVM_OBJECT* SPVM_API_get_field_object(SPVM_ENV* env, SPVM_VALUE* stack, SPVM_OBJECT* object, SPVM_RUNTIME_FIELD* field);
+SPVM_OBJECT** SPVM_API_get_field_object_address(SPVM_ENV* env, SPVM_VALUE* stack, SPVM_OBJECT* object, SPVM_RUNTIME_FIELD* field);
 SPVM_OBJECT* SPVM_API_get_field_string(SPVM_ENV* env, SPVM_VALUE* stack, SPVM_OBJECT* object, SPVM_RUNTIME_FIELD* field);
 
 // Set field
@@ -127,6 +128,7 @@ int64_t SPVM_API_get_field_long_by_name(SPVM_ENV* env, SPVM_VALUE* stack, SPVM_O
 float SPVM_API_get_field_float_by_name(SPVM_ENV* env, SPVM_VALUE* stack, SPVM_OBJECT* object, const char* field_name, int32_t* error_id, const char* func_name, const char* file, int32_t line);
 double SPVM_API_get_field_double_by_name(SPVM_ENV* env, SPVM_VALUE* stack, SPVM_OBJECT* object, const char* field_name, int32_t* error_id, const char* func_name, const char* file, int32_t line);
 SPVM_OBJECT* SPVM_API_get_field_object_by_name(SPVM_ENV* env, SPVM_VALUE* stack, SPVM_OBJECT* object, const char* field_name, int32_t* error_id, const char* func_name, const char* file, int32_t line);
+SPVM_OBJECT** SPVM_API_get_field_object_address_by_name(SPVM_ENV* env, SPVM_VALUE* stack, SPVM_OBJECT* object, const char* field_name, int32_t* error_id, const char* func_name, const char* file, int32_t line);
 SPVM_OBJECT* SPVM_API_get_field_object_defined_and_has_pointer_by_name(SPVM_ENV* env, SPVM_VALUE* stack, void* object, const char* field_name, int32_t* error_id, const char* func_name, const char* file_name, int32_t line);
 const char* SPVM_API_get_field_string_chars_by_name(SPVM_ENV* env, SPVM_VALUE* stack, SPVM_OBJECT* object, const char* field_name, int32_t* error_id, const char* func_name, const char* file, int32_t line);
 SPVM_OBJECT* SPVM_API_get_field_string_by_name(SPVM_ENV* env, SPVM_VALUE* stack, SPVM_OBJECT* object, const char* field_name, int32_t* error_id, const char* func_name, const char* file, int32_t line);
@@ -314,4 +316,6 @@ void* SPVM_API_strerror_string_nolen(SPVM_ENV* env, SPVM_VALUE* stack, int32_t e
 
 int32_t SPVM_API_call_method_vm(SPVM_ENV* env, SPVM_VALUE* stack, SPVM_RUNTIME_METHOD* method, int32_t args_width);
 
+int32_t SPVM_API_check_stack_env(SPVM_ENV* env, SPVM_VALUE* stack);
+
 #endif
