@@ -314,7 +314,7 @@ sub generate_perl_class_file {
   my $description;
   my $main_doc;
   if ($interface) {
-    $description = "The $basic_type_name interface of L<SPVM> has interface methods for someting.";
+    $description = "$basic_type_name interface of L<SPVM> has interface methods for someting.";
     $main_doc  = <<"EOS";
 =head1 Usage
 
@@ -327,7 +327,7 @@ sub generate_perl_class_file {
 EOS
   }
   elsif ($resource) {
-    $description = "The $basic_type_name resource of L<SPVM> is a L<resouce|SPVM::Document::Resource> for someting.";
+    $description = "$basic_type_name resource of L<SPVM> is a L<resouce|SPVM::Document::Resource> for someting.";
     
     my $native = $self->native;
     my $new_method;
@@ -446,7 +446,7 @@ MyClass.$native_module_ext:
 EOS
   }
   else {
-    $description = "The $basic_type_name class of L<SPVM> has methods for someting.";
+    $description = "$basic_type_name class of L<SPVM> has methods for someting.";
     $main_doc  = <<"EOS";
 =head1 Usage
 
