@@ -61,9 +61,9 @@ Examples:
 
   static method new_len : Immutable::FloatList ($length : int);
 
-Creates a new L<Immutable::FloatList|SPVM::Immutable::FloatList> object with the $length.
+Creates a new L<Immutable::FloatList|SPVM::Immutable::FloatList> object with $length.
 
-The $length must be greater than or equal to 0. Otherwise an exception is thrown.
+$length must be greater than or equal to 0. Otherwise an exception is thrown.
 
 =head1 Instance Methods
 
@@ -71,13 +71,13 @@ The $length must be greater than or equal to 0. Otherwise an exception is thrown
 
   method get : float ($index : int);
 
-Gets the element of the position of the $index.
+Gets the element of the position of $index.
 
 Exceptions:
 
-The $index must be greater than or equal to 0. Otherwise an exception is thrown.
+$index must be greater than or equal to 0. Otherwise an exception is thrown.
 
-The $index must be less than the length of the $list.
+$index must be less than the length of $list.
 
 =head2 to_array
 
