@@ -92,7 +92,7 @@ The length of the list.
 
 Creates a new C<List> object using L</"new_len">.
 
-The passed length to L</"new_len"> is the length of the $array. If the array is undef, the length is 0.
+The passed length to L</"new_len"> is the length of $array. If the array is undef, the length is 0.
 
 The element's addresses of the object array are copied to the elements of the the created array.
   
@@ -106,17 +106,17 @@ The element's addresses of the object array are copied to the elements of the th
 
   static method new_len : List ($proto_array : object[], $length : int, $capacity : int = -1);
 
-Creates a new C<StringList> object with the $protot_array, the $length and the $capacity.
+Creates a new C<StringList> object with $protot_array, $length and $capacity.
 
-If the $protot_array is undefined, the $protot_array is set to an C<object[]> object.
+If $protot_array is undefined, $protot_array is set to an C<object[]> object.
 
-If the $capacity is less than 0, the $capacity is set to the value of L</"DEFAULT_CAPACITY">.
+If $capacity is less than 0, $capacity is set to the value of L</"DEFAULT_CAPACITY">.
 
-If the $length is greater than the $capacity, the $capacity is set to the length.
+If $length is greater than $capacity, $capacity is set to the length.
 
 Exceptions:
 
-The $length must be greater than or equal to 0. Otherwise an exception is thrown.
+$length must be greater than or equal to 0. Otherwise an exception is thrown.
 
 Examples:
 
@@ -129,25 +129,25 @@ Examples:
 
   method get : object ($index : int);
 
-Gets the element of the position of the $index.
+Gets the element of the position of $index.
 
 Exceptions:
 
-The $index must be greater than or equal to 0. Otherwise an exception is thrown.
+$index must be greater than or equal to 0. Otherwise an exception is thrown.
 
-The $index must be less than the length of the $list. Otherwise an exception is thrown.
+$index must be less than the length of $list. Otherwise an exception is thrown.
 
 =head2 insert
 
   method insert : void ($index : int, $element : object);
 
-Inserts an $element to the position of the $index.
+Inserts an $element to the position of $index.
 
 Exceptions:
 
-The $index must be greater than or equal to 0. Otherwise an exception is thrown.
+$index must be greater than or equal to 0. Otherwise an exception is thrown.
 
-The $index must be less than or equal to the length of the $list. Otherwise an exception is thrown.
+$index must be less than or equal to the length of $list. Otherwise an exception is thrown.
 
 =head2 pop
 
@@ -157,7 +157,7 @@ Removes the last element and return it.
 
 Exceptions:
 
-The length of the $list must be greater than 0. Otherwise an exception is thrown.
+The length of $list must be greater than 0. Otherwise an exception is thrown.
             
 =head2 push
   
@@ -169,87 +169,87 @@ Adds an $element after the end of the list.
 
   method remove : object ($index : int);
 
-Removes the element at the position of the $index and return it.
+Removes the element at the position of $index and return it.
 
 Exceptions:
 
-The $index must be greater than or equal to 0. Otherwise an exception is thrown.
+$index must be greater than or equal to 0. Otherwise an exception is thrown.
 
-The $index must be less than the length of the $list. Otherwise an exception is thrown.
+$index must be less than the length of $list. Otherwise an exception is thrown.
 
 =head2 replace
 
   method replace : void ($offset : int, $remove_length : int, $replace : string[]);
 
-Replaces the elements of the range specified by the $offset and the $lenght with the $replace array.
+Replaces the elements of the range specified by $offset and $lenght with $replace array.
 
 Exceptions:
 
-The $offset must be greater than or equal to 0. Otherwise an exception is thrown.
+$offset must be greater than or equal to 0. Otherwise an exception is thrown.
 
-The $remove_length must be greater than or equal to 0. Otherwise an exception is thrown.
+$remove_length must be greater than or equal to 0. Otherwise an exception is thrown.
 
-The $offset + the $removing lenght must be less than or equal to the length of the $list. Otherwise an exception is thrown.
+$offset + $removing lenght must be less than or equal to the length of $list. Otherwise an exception is thrown.
 
 =head2 reserve
 
   method reserve : void ($new_capacity : int);
 
-Reserves the elements with the $new_capacity.
+Reserves the elements with $new_capacity.
 
-If the $new_capacity is greater than the capacity of the list, the capacity of the list is extended to the $new_capacity.
+If $new_capacity is greater than the capacity of the list, the capacity of the list is extended to $new_capacity.
 
 Exceptions:
 
-The $new_capacity must be greater than or equal to 0. Otherwise an exception is thrown.
+$new_capacity must be greater than or equal to 0. Otherwise an exception is thrown.
 
 =head2 resize
 
   method resize : void ($new_length : int);
 
-Resize the list with the $new_length.
+Resize the list with $new_length.
 
 Exceptions:
 
-The $new_length must be greater than or equal to 0. Otherwise an exception is thrown.
+$new_length must be greater than or equal to 0. Otherwise an exception is thrown.
 
 =head2 replace
 
   method replace : void ($offset : int, $remove_length : int, $replace : object[]);
 
-Replaces the elements of the range specified by the $offset and the $remove_length with the replacement array.
+Replaces the elements of the range specified by $offset and $remove_length with the replacement array.
 
 Exceptions:
 
-The $offset must be greater than or equal to 0. Otherwise an exception is thrown.
+$offset must be greater than or equal to 0. Otherwise an exception is thrown.
 
-The $remove_length must be greater than or equal to 0. Otherwise an exception is thrown.
+$remove_length must be greater than or equal to 0. Otherwise an exception is thrown.
 
-The $offset + the $removing lenght must be less than or equal to the length of the $list. Otherwise an exception is thrown.
+$offset + $removing lenght must be less than or equal to the length of $list. Otherwise an exception is thrown.
 
 =head2 set
 
   method set : void ($index : int, $element : object);
 
-Sets the $element at the position of the $index.
+Sets $element at the position of $index.
 
 Exceptions:
 
-The $index must be greater than or equal to 0. Otherwise an exception is thrown.
+$index must be greater than or equal to 0. Otherwise an exception is thrown.
 
-The $index must be less than the length of the $list. Otherwise an exception is thrown.
+$index must be less than the length of $list. Otherwise an exception is thrown.
 
 =head2 set_array
 
   method set_array : void ($array : object[]);
 
-Sets an $array. Each element of the $array is copied to the element of the list.
+Sets an $array. Each element of $array is copied to the element of the list.
 
 Exceptions:
 
-The $array must be defined. Otherwise an exception is thrown.
+$array must be defined. Otherwise an exception is thrown.
 
-The length of the $array must be the $same as the length of the $list. Otherwise an exception is thrown.
+The length of $array must be equal to the length of $list. Otherwise an exception is thrown.
 
 =head2 shift
 
@@ -259,7 +259,7 @@ Removes the first element and return it.
 
 Exceptions:
 
-The length of the $list must be greater than 0. Otherwise an exception is thrown.
+The length of $list must be greater than 0. Otherwise an exception is thrown.
 
 =head2 to_array
 
