@@ -96,15 +96,15 @@ Examples:
 
   static method new_len : ShortList ($length : int, $capacity : int = -1);
 
-Creates a new C<ShortList> object with the $length and the $capacity.
+Creates a new C<ShortList> object with $length and $capacity.
 
-If the $capacity is less than 0, the capacity is set to the value of L</"DEFAULT_CAPACITY">.
+If $capacity is less than 0, the capacity is set to the value of L</"DEFAULT_CAPACITY">.
 
-If the $length is greater than the $capacity, the $capacity is set to the $length.
+If $length is greater than $capacity, $capacity is set to $length.
 
 Exceptions:
 
-The $length must be greater than or equal to 0. Otherwise an exception is thrown.
+$length must be greater than or equal to 0. Otherwise an exception is thrown.
 
 =head1 Instance Methods
 
@@ -112,25 +112,25 @@ The $length must be greater than or equal to 0. Otherwise an exception is thrown
 
   method get : int ($index : int);
 
-Gets the element of the position of the $index.
+Gets the element of the position of $index.
 
 Exceptions:
 
-The $index must be greater than or equal to 0. Otherwise an exception is thrown.
+$index must be greater than or equal to 0. Otherwise an exception is thrown.
 
-The $index must be less than the length of the $list. Otherwise an exception is thrown.
+$index must be less than the length of $list. Otherwise an exception is thrown.
 
 =head2 insert
 
   method insert : void ($index : int, $element : int);
 
-Inserts an $element to the position of the $index.
+Inserts an $element to the position of $index.
 
 Exceptions:
 
-The $index must be greater than or equal to 0. Otherwise an exception is thrown.
+$index must be greater than or equal to 0. Otherwise an exception is thrown.
 
-The $index must be less than or equal to the length of the $list. Otherwise an exception is thrown.
+$index must be less than or equal to the length of $list. Otherwise an exception is thrown.
 
 =head2 pop
 
@@ -140,7 +140,7 @@ Removes the last element and return it.
 
 Exceptions:
 
-The length of the $list must be greater than 0. Otherwise an exception is thrown.
+The length of $list must be greater than 0. Otherwise an exception is thrown.
 
 =head2 push
   
@@ -152,73 +152,73 @@ Adds an $element after the end of the list.
 
   method remove : int ($index : int);
 
-Removes the element at the position of the $index and return it.
+Removes the element at the position of $index and return it.
 
 Exceptions:
 
-The $index must be greater than or equal to 0. Otherwise an exception is thrown.
+$index must be greater than or equal to 0. Otherwise an exception is thrown.
 
-The $index must be less than the length of the $list. Otherwise an exception is thrown.
+$index must be less than the length of $list. Otherwise an exception is thrown.
 
 =head2 replace
 
   method replace : void ($offset : int, $remove_length : int, $replace : short[]);
 
-Replaces the elements of the range specified by the $offset and the $lenght with the $replace array.
+Replaces the elements of the range specified by $offset and $lenght with $replace array.
 
 Exceptions:
 
-The $offset must be greater than or equal to 0. Otherwise an exception is thrown.
+$offset must be greater than or equal to 0. Otherwise an exception is thrown.
 
-The $remove_length must be greater than or equal to 0. Otherwise an exception is thrown.
+$remove_length must be greater than or equal to 0. Otherwise an exception is thrown.
 
-The $offset + the $removing lenght must be less than or equal to the length of the $list. Otherwise an exception is thrown.
+$offset + $removing lenght must be less than or equal to the length of $list. Otherwise an exception is thrown.
 
 =head2 reserve
 
   method reserve : void ($new_capacity : int);
 
-Reserves the elements with the $new_capacity.
+Reserves the elements with $new_capacity.
 
-If the $new_capacity is greater than the capacity of the list, the capacity of the list is extended to the $new_capacity.
+If $new_capacity is greater than the capacity of the list, the capacity of the list is extended to $new_capacity.
 
 Exceptions:
 
-The $new_capacity must be greater than or equal to 0. Otherwise an exception is thrown.
+$new_capacity must be greater than or equal to 0. Otherwise an exception is thrown.
 
 =head2 resize
 
   method resize : void ($new_length : int);
 
-Resize the list with the $new_length.
+Resize the list with $new_length.
 
 Exceptions:
 
-The $new_length must be greater than or equal to 0. Otherwise an exception is thrown.
+$new_length must be greater than or equal to 0. Otherwise an exception is thrown.
 
 =head2 set
 
   method set : void ($index : int, $element : int);
 
-Sets the $element at the position of the $index.
+Sets $element at the position of $index.
 
 Exceptions:
 
-The $index must be greater than or equal to 0. Otherwise an exception is thrown.
+$index must be greater than or equal to 0. Otherwise an exception is thrown.
 
-The $index must be less than the length of the $list. Otherwise an exception is thrown.
+$index must be less than the length of $list. Otherwise an exception is thrown.
 
 =head2 set_array
 
   method set_array : void ($array : short[]);
 
-Sets an $array. Each element of the $array is copied to the element of the list.
+Sets an $array. Each element of $array is copied to the element of the list.
 
 Exceptions:
 
-The $array must be defined.
+$array must be defined.
 
-The length of the $array must be the $same as the length of the $list. Otherwise an exception is thrown.
+The length of $array must be equal to the length of $list. Otherwise an exception is thrown.
 
 =head2 shift
 
@@ -228,7 +228,7 @@ Removes the first element and return it.
 
 Exceptions:
 
-The length of the $list must be greater than 0. Otherwise an exception is thrown.
+The length of $list must be greater than 0. Otherwise an exception is thrown.
 
 =head2 to_array
 
